#######################################################################
# Copyright (c) 2025 ENEO Tecnologia S.L.
# This file is part of redBorder.
# redBorder is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# redBorder is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# You should have received a copy of the GNU Affero General Public License
# along with redBorder. If not, see <http://www.gnu.org/licenses/>.
#######################################################################

class AutomaticAction < ApplicationRecord
  # ==========================================================
  # Relations
  # ==========================================================

  belongs_to :playbook

  def execute(response_action)
    parsed_params = self.parse_hash_if_needed(self.params)

    Delayed::Job.enqueue(
      Redborder::Jobs::ResponseActionJob.new(true, User.first.id, response_action.id, self.integration_service, self.action, parsed_params),
      priority: 10,
      run_at: Time.now + 2.seconds
    )
  end

  private

  def parse_hash_if_needed(value)
    result = {}
    begin
      parsed = JSON.parse(value.gsub('=>', ':'))
      if parsed.is_a?(Hash)
        parsed.each do |key, param|
          if param.is_a?(Hash)
            result[key.to_sym] = param.to_json
          else
            result[key.to_sym] = param
          end
        end
      else
      end
    rescue JSON::ParseError => e
      Rails.logger.error "Error parsing the atuomatic actuin param: #{e.message}"
    end
    result
  end
end
