/*!
 * Copyright (c) 2014 ENEO Tecnología S.L.
 * This file is part of redBorder.
 * redBorder is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * redBorder is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * You should have received a copy of the GNU Affero General Public License
 * along with redBorder. If not, see <http://www.gnu.org/licenses/>.
 */
// Detect click on a cluster node to filter the view 
$(document).on('click', '.cluster-status', function(event) {
  event.preventDefault();

  var el = $(this);
  var states = ["ok", "warning", "error"];
  var badgeState = null;

  // Seach badge status
  el.attr("class").split(" ").forEach(function(cls) {
      if (states.indexOf(cls) !== -1) {
          badgeState = cls;
      }
  });

  if (!badgeState) return;

  if (el.hasClass('filtered')) {
    clusterRemoveFilters($('.cluster-status.filtered'));
    clusterRemoveFilters($('.cluster-filter.filtered'));
    return;
  }

  clusterRemoveFilters($('.cluster-status.filtered'));
  clusterRemoveFilters($('.cluster-filter.filtered'));

  el.addClass('filtered');


  // Apply class to all card that match status
  $('.cluster-card').each(function() {
      var card = $(this);

      if (card.hasClass(badgeState)) {
          card.addClass('reference').removeClass('not-reference');
      } else {
          card.addClass('not-reference').removeClass('reference');
      }
  });
});

$(document).on('click', '.cluster-filter', function(event){
  event.preventDefault();

  var el = $(this),
      name;

  if (el.data('name') !== undefined){
    name = el.data('name');
  } else {
    name = el.parents('.cluster-node').data('name');
  }

  if (el.hasClass('filtered')){
    clusterRemoveFilters($('.cluster-status.filtered'));
    clusterRemoveFilters($('.cluster-filter.filtered'));
    return;
  } else if (name == 'error' || name == 'warning' || name == 'ok') {
    clusterRemoveFilters($('.cluster-status.filtered'));
    clusterRemoveFilters($('.cluster-filter.filtered'));
    var type = el.data('type')
    el.addClass('filtered');
    var elements;
    if (type == 'all'){
      elements = $('.cluster-card');
    } else {
      elements = $(type + ' .cluster-card');
      $('.cluster-cards:not('+ type +') .cluster-card').addClass('not-reference');
    }
    elements.each(function() {
      var card = $(this);
      if(card.hasClass(name)){
        card.addClass('reference');
      } else {
        card.addClass('not-reference');
      }
    });
  } else {
    clusterRemoveFilters($('.cluster-status.filtered'));
    clusterRemoveFilters($('.cluster-filter.filtered'));
    el.addClass('filtered');
    $('.cluster-card').each(function() {
      var card = $(this);
      var cardRef = card.data('reference');
      var cardName = card.data('name');

      var refArray = cardRef ? cardRef.split(/\s*,\s*/) : [];
      var nameArray = cardName ? cardName.split(/\s*,\s*/) : [];

      if (refArray.indexOf(name) !== -1) {
          card.addClass('reference');
      } else if (nameArray.indexOf(name) !== -1) {
          card.addClass('reference');
      } else {
          card.addClass('not-reference');
      }
    });
  }
});

function clusterRemoveFilters(element){
  element.removeClass('filtered');
  $('.cluster-card.not-reference').removeClass('not-reference');
  $('.cluster-card.reference').removeClass('reference');
}

$(document).ready(function () {
  var activeTab = document.querySelector(".toggle-tab.active-tab");
  if (activeTab) {
      activeTab.classList.add("selected");
  }

  $('.ccard-content').each(function() {
    var card = $(this);
    var tabContent = card.find(".tab-content")[0];
    var tabs = card.find(".tab-pane");

    if (!tabContent || tabs.length === 0) return;

    var maxHeight = 0;
    var maxWidth = 0;

    // Show all tabs temporarily to calculate max dimensions
    tabs.each(function() {
      var tab = $(this)[0];
      tab.style.display = "block";
      var height = tab.offsetHeight;
      var width = tab.offsetWidth;

      maxHeight = Math.max(maxHeight, height);
      maxWidth = Math.max(maxWidth, width);
      tab.style.display = "";
    });

    // Set a fixed size to avoid shifting layout
    tabContent.style.minHeight = maxHeight + "px";
    tabContent.style.minWidth = maxWidth + "px";

    // Add event listener for tab switching
    $('.toggle-tab').each(function() {
      $(this).on("click", function (event) {
        event.preventDefault();
        var targetId = this.dataset.target;
        var targetTab = card.find(targetId)[0];

        if (!targetTab) {
          console.error("Target tab not found:", targetId);
          return;
        }

        // Remove active state from all tabs & buttons within this card
        card.find(".tab-pane").removeClass("in active");
        card.find(".toggle-tab").removeClass("active-tab");

        // Activate the selected tab
        $(targetTab).addClass("in active");
        $(this).addClass("active-tab");
      });
    });
  });
});

/* --------------------------------
 *  Show the payload
 * -------------------------------- */

$(document).on('click', '.task-payload', function(event){
  event.preventDefault();
  var json_payload = JSON.stringify($(this).data('payload'), undefined, 2);

  redBorder.modals.showModalWith(
    I18n.t('javascript.payload'),
    '<pre class="pretty-json">' + JSONSyntaxHighlight(json_payload) + '</pre>',
    redBorder.modals.dismissButton('Back'),
    '#default_large'
  )
});

/* --------------------------------
 *  Copy the id
 * -------------------------------- */

function prepare_copy_id_tasks(){
  if(detectFlashSupport()){
    var client = new ZeroClipboard($(".cluster-task-copy-id"));

    client.on('ready', function(event) {
      client.on('copy', function(event) {
        var clipboard = event.clipboardData;
        var id = $(event.target).data('id');
        clipboard.setData("text/plain", id);
      });

      // callback triggered on successful copying
      client.on('aftercopy', function(event) {
        var el = $(event.target);
        $(event.target).parent().find('.tooltip-inner').text('Task ID is copied!')
      });
    });

    // In case of error - such as Flash not being available
    client.on('error', function() {
      ZeroClipboard.destroy();
      $(".cluster-task-copy-id").addClass('.cluster-task-copy-id-alt');
    });

  } else {
    $(".cluster-task-copy-id").addClass('.cluster-task-copy-id-alt');
  }
}

/* --------------------------------
 *  Show the id
 * -------------------------------- */

$(document).on('click', '.cluster-task-copy-id-alt', function(event){
  event.preventDefault();
  redBorder.modals.showModalWith(
    I18n.t('javascript.identifier'),
    '<pre>' + $(this).data('id') + '</pre>',
    redBorder.modals.dismissButton('Back'),
    '#default_large'
  )
});

/* --------------------------------
 *  Filter by task status
 * -------------------------------- */

$(document).on('click', '.task-status-ratio .percent-item', function(event){
  var item = $(this);

  if(item.hasClass('filtered')){
    item.removeClass('filtered');
    item.siblings('.percent-item').removeClass('not-filtered');
    // Restore
    $.ajax({
      url: '/monitor/load_more_tasks?page=1&type=complete',
      type: 'GET',
      dataType: 'script',
      cache: false
    });
  } else {
    item.removeClass('not-filtered').addClass('filtered');
    item.siblings('.percent-item').removeClass('filtered').addClass('not-filtered');

    var status;
    if(item.hasClass('green')){
      status = 'success';
    } else {
      status = 'failed';
    }

    // Restore
    $.ajax({
      url: '/monitor/complete_tasks?status=' + status,
      type: 'GET',
      dataType: 'script',
      cache: false
    });
  }
});

$(document).on('click', '.task-namespace-filter', function(event){
  event.preventDefault();
  var item = $(this),
      tab = item.parent().data('tab');

  if(item.hasClass('btn-success')){
    item.removeClass('btn-success');
    // Restore
    $.ajax({
      url: '/monitor/load_more_tasks?page=1&type=' + tab,
      type: 'GET',
      dataType: 'script',
      cache: false
    });
  } else {
    // Filter
    item.addClass('btn-success');
    item.siblings('.task-namespace-filter').removeClass('btn-success');
    // Get data
    $.ajax({
      url: '/monitor/namespace_tasks?namespace=' + item.data('namespace') + '&tab=' + tab,
      type: 'GET',
      dataType: 'script',
      cache: false
    });
  }
});
