require 'test_helper'

#
# Test alerts controller
#
class AlarmsControllerTest < ActionController::TestCase
  include Warden::Test::Helpers
  Warden.test_mode!

  context 'an admin user' do
    setup do
      @user = users(:admin_domain)
      sign_in @user
    end

    should 'delete alarms in the domain he is in' do
      alarm = alarms(:one)
      assert_difference 'Alarm.count', -1 do
        delete :destroy, id: alarm.id # Alarm one
      end
    end

    should 'delete alarms that are in sensors he has permission' do
      alarm = alarms(:two)
      assert_difference 'Alarm.count', -1 do
        delete :destroy, id: alarm.id # Alarm two
      end
    end

    should 'not delete alarms that are in sensors he does not have permission' do
      alarm = alarms(:three)
      assert_no_difference 'Alarm.count' do
        delete :destroy, id: alarm.id # Alarm three
      end
    end
  end

  context 'a super admin user' do
    setup do
      @user = users(:admin)
      sign_in @user
    end

    should 'delete any alarm' do
      alarm = alarms(:five)
      assert_difference 'Alarm.count', -1 do
        delete :destroy, id: alarm.id # Alarm five
      end
    end
  end

  context 'a non admin user' do
    setup do
      @user = users(:user_domain)
      sign_in @user
    end

    should 'not delete any alarm' do
      alarm = alarms(:four)
      assert_no_difference 'Alarm.count' do
        delete :destroy, id: alarm.id # Alarm five
      end
    end
  end
  
end
